@@ -1,10 +1,11 @@
 # -*- encoding: utf-8 -*-
 """Evergreen representation of a project."""
-from __future__ import absolute_import, annotations
+from __future__ import absolute_import
 
 from typing import Any, Dict, TYPE_CHECKING
 
 from evergreen.base import _BaseEvergreenObject, evg_attrib
+from evergreen.version import Version
 
 if TYPE_CHECKING:
     from evergreen.api import EvergreenApi
@@ -29,7 +30,7 @@ class Project(_BaseEvergreenObject):
     pr_testing_enabled = evg_attrib("pr_testing_enabled")
     commit_queue = evg_attrib("commit_queue")
 
-    def __init__(self, json: Dict[str, Any], api: EvergreenApi) -> None:
+    def __init__(self, json: Dict[str, Any], api: "EvergreenApi") -> None:
         """
         Create an instance of an evergreen project.
 
@@ -41,3 +42,12 @@ class Project(_BaseEvergreenObject):
     def __str__(self) -> str:
         """Get a string version of the Project."""
         return self.identifier
+
+    def most_recent_version(self) -> Version:
+        """
+        Fetch the most recent version.
+
+        :return: Version queried for.
+        """
+        version_iterator = self._api.versions_by_project(self.identifier)
+        return next(version_iterator)
